clj-format.directives

Directive metadata and dispatch rules shared by the parser and compiler.

Directive metadata and dispatch rules shared by the parser and compiler.
raw docstring

+case-keywords+clj

Case-conversion wrapper directives.

Case-conversion wrapper directives.
sourceraw docstring

+case-open+clj

Maps case conversion mode keywords to their cl-format opening strings.

Maps case conversion mode keywords to their cl-format opening strings.
sourceraw docstring

+char->simple+clj

Map of simple directive chars to parser/compiler metadata.

Map of simple directive chars to parser/compiler metadata.
sourceraw docstring

+compound-directives+clj

True compound directives whose syntax is structurally bracketed.

True compound directives whose syntax is structurally bracketed.
sourceraw docstring

+compound-keywords+clj

Keywords that represent non-case compound directives.

Keywords that represent non-case compound directives.
sourceraw docstring

+simple-directives+clj

Simple char-backed directives with their real parameter and flag metadata.

Simple char-backed directives with their real parameter and flag metadata.
sourceraw docstring

+special-chars+clj

Characters with special dispatch in the parser.

Characters with special dispatch in the parser.
sourceraw docstring

+special-keywords+clj

Keywords produced by or compiled through special dispatch.

Keywords produced by or compiled through special dispatch.
sourceraw docstring

compound-directive-configclj

(compound-directive-config kw)

Return metadata for a compound directive keyword.

Return metadata for a compound directive keyword.
sourceraw docstring

directive-configclj

(directive-config kw)

Return metadata for any known directive keyword.

Return metadata for any known directive keyword.
sourceraw docstring

known-directive-keyword?clj

(known-directive-keyword? kw)

True when kw names a known DSL directive or wrapper.

True when `kw` names a known DSL directive or wrapper.
sourceraw docstring

parse-specialclj

(parse-special char positional-params raw-flags)

Translate a special-dispatch directive to DSL form.

Translate a special-dispatch directive to DSL form.
sourceraw docstring

positional->namedclj

(positional->named param-names params)

Convert positional params to a named map using the given name list. Nil values are omitted.

Convert positional params to a named map using the given name list.
Nil values are omitted.
sourceraw docstring

raw->optsclj

(raw->opts kw-or-config positional-params raw-flags)

Convert raw cl-format params and flags to a semantic opts map. kw-or-config is either a directive keyword or a config map.

Convert raw cl-format params and flags to a semantic opts map.
kw-or-config is either a directive keyword or a config map.
sourceraw docstring

simple-directive-configclj

(simple-directive-config kw)

Return metadata for a simple directive keyword.

Return metadata for a simple directive keyword.
sourceraw docstring

special->rawclj

(special->raw kw opts)

Translate a special-dispatch DSL form to raw compile metadata.

Translate a special-dispatch DSL form to raw compile metadata.
sourceraw docstring

special-directive-configclj

(special-directive-config kw)

Return derived metadata for a special-dispatch keyword.

Return derived metadata for a special-dispatch keyword.
sourceraw docstring

translate-flagsclj

(translate-flags raw-flags flag-map)

Translate raw colon/at flags to semantic options using a flag-map.

Translate raw colon/at flags to semantic options using a flag-map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries