Directive metadata and dispatch rules shared by the parser and compiler.
Directive metadata and dispatch rules shared by the parser and compiler.
Case-conversion wrapper directives.
Case-conversion wrapper directives.
Maps case conversion mode keywords to their cl-format opening strings.
Maps case conversion mode keywords to their cl-format opening strings.
Map of simple directive chars to parser/compiler metadata.
Map of simple directive chars to parser/compiler metadata.
True compound directives whose syntax is structurally bracketed.
True compound directives whose syntax is structurally bracketed.
Keywords that represent non-case compound directives.
Keywords that represent non-case compound directives.
Simple char-backed directives with their real parameter and flag metadata.
Simple char-backed directives with their real parameter and flag metadata.
Characters with special dispatch in the parser.
Characters with special dispatch in the parser.
Keywords produced by or compiled through special dispatch.
Keywords produced by or compiled through special dispatch.
(compound-directive-config kw)Return metadata for a compound directive keyword.
Return metadata for a compound directive keyword.
(directive-config kw)Return metadata for any known directive keyword.
Return metadata for any known directive keyword.
(known-directive-keyword? kw)True when kw names a known DSL directive or wrapper.
True when `kw` names a known DSL directive or wrapper.
(parse-special char positional-params raw-flags)Translate a special-dispatch directive to DSL form.
Translate a special-dispatch directive to DSL form.
(positional->named param-names params)Convert positional params to a named map using the given name list. Nil values are omitted.
Convert positional params to a named map using the given name list. Nil values are omitted.
(raw->opts kw-or-config positional-params raw-flags)Convert raw cl-format params and flags to a semantic opts map. kw-or-config is either a directive keyword or a config map.
Convert raw cl-format params and flags to a semantic opts map. kw-or-config is either a directive keyword or a config map.
(simple-directive-config kw)Return metadata for a simple directive keyword.
Return metadata for a simple directive keyword.
(special->raw kw opts)Translate a special-dispatch DSL form to raw compile metadata.
Translate a special-dispatch DSL form to raw compile metadata.
(special-directive-config kw)Return derived metadata for a special-dispatch keyword.
Return derived metadata for a special-dispatch keyword.
(translate-flags raw-flags flag-map)Translate raw colon/at flags to semantic options using a flag-map.
Translate raw colon/at flags to semantic options using a flag-map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |